function M = relax(P,Mi,T)
%
% Purpose : Compute the magnetization vector in voxel P
% after a relaxation process of duration T
%
% Arguments in :
% Mi : initial magnetisation vector
% T  : relaxation process duration
% P : voxel location (not used in the curent version)
% Arguments out :
% M  : the magnetisation vector
%
% ARAMIS - (c) S. Balac - ENSSAT - Université de Rennes 1 - 2007 (version 2.0)
%

global omega

M(1) = Mi(1)*cos(omega*T) +  Mi(2)*sin(omega*T);
M(2) = - Mi(1)*sin(omega*T) +  Mi(2)*cos(omega*T);
M(3) = Mi(3);
